@@ -28,12 +28,13 @@ class instrument:
         self.MaiTai.baud_rate = 115200
         self.OnButton.on_click(self.On)
         self.OffButton.on_click(self.Off)
-        self.CloseButton.on_click(self.Close)
+        self.CloseButton.on_click(self.CloseShutter)
+        self.OpenButton.on_click(self.OpenShutter)
 
-    def CloseShutter(self):
+    def CloseShutter(self, event=None):
         self.Shutter(0)
 
-    def OpenShutter(self):
+    def OpenShutter(self,event=None):
         self.Shutter(1)
 
     def Shutter(self, val=0):
