@@ -12,7 +12,7 @@ class instrument:
         pass
 
     def Power(self):
-        return random.Random.randint(0, 100)
+        return random.randint(0, 100)
 
     def PowAvg(self):
         P = []
