@@ -10,8 +10,6 @@ here = str(Path(__file__).resolve().parent)
 directory_name = here.replace(str(Path(__file__).resolve().parent.parent), "").replace("/", "")  # gross solution
 instruments = {}
 
-
-
 for directory in os.scandir(here):
     if directory.is_dir() and not directory.name.__contains__("__"):
         modules = {}
@@ -25,7 +23,12 @@ for directory in os.scandir(here):
                         serial = module.serial_number
                     except:
                         serial = "any"
-                    modules[module.name] = {"name": module.name, "module": module, "hwid": module.hwid,"serial": serial}
+                    try:
+                        function = module.get_devices
+                    except:
+                        function = "default"
+                    modules[module.name] = {"name": module.name, "module": module, "hwid": module.hwid,
+                                            "serial": serial, "function": function}
                 except Exception as ex:
                     print(f"{file} import failed")
                     print(ex)
@@ -49,8 +52,12 @@ for directory in os.scandir(here):
                         serial = module.serial_number
                     except:
                         serial = "any"
-
-                    modules = {name: {"name": name, "module": module, "hwid": hwid, "serial": serial}}
+                    try:
+                        function = module.get_devices
+                    except:
+                        function = "default"
+                    modules = {
+                        name: {"name": name, "module": module, "hwid": hwid, "serial": serial, "function": function}}
                     globals()[name] = Instrument(modules=modules, name=name)
                 except:
                     name = sname
@@ -60,4 +67,3 @@ for directory in os.scandir(here):
             except Exception as ex:
                 print(f"{file} import failed")
                 print(ex)
-
